==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/reef/dialogs_es.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("¡Mi dios, el impacto creó una caverna!")


dialogId("uts-v-projet0", "font_big", "I can`t go through this cave-in, we have to find another exit.")
dialogStr("No puedo avanzar por esta caverna, tenemos que encontrar otra salida.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Este no es el camino.")


dialogId("uts-v-sam", "font_big", "I won`t make it alone.")
dialogStr("No lo haré solo.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Yo probablemente debería haber levantado esa concha primero.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Quizás tenemos que intercambiar esos objetos.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Un colchón. Lo mejor que puedes conseguir bajo el agua.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Ahora podemos hacer caer el caracol en el colchón.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Será difícil recoger el caracol desde ahí.")


dialogId("uts-v-konecne", "font_big", "Finally, it`s there.")
dialogStr("Finalmente, está allí.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("El pobre caracol...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Deberíamos de buscar en los arrecifes de coral.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Habrán muchos seres interesantes para investigar aquí.")


dialogId("uts-v-mikroskop", "font_big", "Don`t we need a microscope to investigate corals?")
dialogStr("¿No necesitamos un microscopio para investigar corales?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Si, son pequeños. Pero pueden haber otras formas de vida.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Tortugas de coral, por ejemplo.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Y además sospecho que hay un microscopio en un batiscafo.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/reef/dialogs_es.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("¡Mi dios, el impacto creó una caverna!")


dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("No puedo avanzar por esta caverna, tenemos que encontrar otra salida.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Este no es el camino.")


dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("No lo haré solo.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Yo probablemente debería haber levantado esa concha primero.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Quizás tenemos que intercambiar esos objetos.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Un colchón. Lo mejor que puedes conseguir bajo el agua.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Ahora podemos hacer caer el caracol en el colchón.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Será difícil recoger el caracol desde ahí.")


dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Finalmente, está allí.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("El pobre caracol...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Deberíamos de buscar en los arrecifes de coral.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Habrán muchos seres interesantes para investigar aquí.")


dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("¿No necesitamos un microscopio para investigar corales?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Si, son pequeños. Pero pueden haber otras formas de vida.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Tortugas de coral, por ejemplo.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Y además sospecho que hay un microscopio en un batiscafo.")
